@@ -8,9 +8,9 @@ import (
 	"runtime"
 	"time"
 
-	"github.com/yosebyte/nodepass/internal"
-	"github.com/yosebyte/nodepass/pkg/cert"
-	"github.com/yosebyte/nodepass/pkg/logs"
+	"github.com/NodePassProject/nodepass-apt/internal"
+	"github.com/NodePassProject/nodepass-apt/pkg/cert"
+	"github.com/NodePassProject/nodepass-apt/pkg/logs"
 )
 
 // start 启动核心逻辑
@@ -21,14 +21,14 @@ func start(args []string) error {
 
 	parsedURL, err := url.Parse(args[1])
 	if err != nil {
-		return fmt.Errorf("start: parse URL failed: %v", err)
+		return fmt.Errorf("start: parse URL failed: %w", err)
 	}
 
 	logger := initLogger(parsedURL.Query().Get("log"))
 
 	core, err := createCore(parsedURL, logger)
 	if err != nil {
-		return fmt.Errorf("start: create core failed: %v", err)
+		return fmt.Errorf("start: create core failed: %w", err)
 	}
 
 	core.Run()
@@ -70,40 +70,33 @@ func createCore(parsedURL *url.URL, logger *logs.Logger) (interface{ Run() }, er
 		tlsCode, tlsConfig := getTLSProtocol(parsedURL, logger)
 		return internal.NewMaster(parsedURL, tlsCode, tlsConfig, logger, version)
 	default:
-		return nil, fmt.Errorf("unknown core: %v", parsedURL)
+		return nil, fmt.Errorf("createCore: unknown core: %v", parsedURL)
 	}
 }
 
 // getTLSProtocol 获取TLS配置
 func getTLSProtocol(parsedURL *url.URL, logger *logs.Logger) (string, *tls.Config) {
 	// 生成基本TLS配置
-	tlsConfig, err := cert.NewTLSConfig(version)
+	tlsConfig, err := cert.NewTLSConfig("")
 	if err != nil {
-		logger.Error("Generate failed: %v", err)
+		logger.Error("Generate TLS config failed: %v", err)
 		logger.Warn("TLS code-0: nil cert")
 		return "0", nil
 	}
 
 	tlsConfig.MinVersion = tls.VersionTLS13
-	tlsCode := parsedURL.Query().Get("tls")
-
-	switch tlsCode {
-	case "0":
-		// 不使用加密
-		logger.Info("TLS code-0: unencrypted")
-		return tlsCode, nil
 
+	switch parsedURL.Query().Get("tls") {
 	case "1":
-		// 使用内存中的证书
+		// 使用内存自签证书
 		logger.Info("TLS code-1: RAM cert with TLS 1.3")
-		return tlsCode, tlsConfig
-
+		return "1", tlsConfig
 	case "2":
 		// 使用自定义证书
 		crtFile, keyFile := parsedURL.Query().Get("crt"), parsedURL.Query().Get("key")
 		cert, err := tls.LoadX509KeyPair(crtFile, keyFile)
 		if err != nil {
-			logger.Error("Cert load failed: %v", err)
+			logger.Error("Certificate load failed: %v", err)
 			logger.Warn("TLS code-1: RAM cert with TLS 1.3")
 			return "1", tlsConfig
 		}
@@ -118,7 +111,7 @@ func getTLSProtocol(parsedURL *url.URL, logger *logs.Logger) (string, *tls.Confi
 				if time.Since(lastReload) >= internal.ReloadInterval {
 					newCert, err := tls.LoadX509KeyPair(crtFile, keyFile)
 					if err != nil {
-						logger.Error("Cert reload failed: %v", err)
+						logger.Error("Certificate reload failed: %v", err)
 					} else {
 						logger.Debug("TLS cert reloaded: %v", crtFile)
 						cachedCert = newCert
@@ -134,10 +127,9 @@ func getTLSProtocol(parsedURL *url.URL, logger *logs.Logger) (string, *tls.Confi
 		} else {
 			logger.Warn("TLS code-2: unknown cert name with TLS 1.3")
 		}
-		return tlsCode, tlsConfig
-
+		return "2", tlsConfig
 	default:
-		// 默认不使用加密
+		// 不使用加密
 		logger.Warn("TLS code-0: unencrypted")
 		return "0", nil
 	}
@@ -145,19 +137,8 @@ func getTLSProtocol(parsedURL *url.URL, logger *logs.Logger) (string, *tls.Confi
 
 // exit 退出程序并显示帮助信息
 func exit(err error) {
-	errMsg1, errMsg2 := "", ""
 	if err != nil {
-		errStr := "FAILED: " + err.Error()
-		if len(errStr) > 35 {
-			errMsg1 = errStr[:35]
-			if len(errStr) > 70 {
-				errMsg2 = errStr[35:67] + "..."
-			} else {
-				errMsg2 = errStr[35:]
-			}
-		} else {
-			errMsg1 = errStr
-		}
+		fmt.Fprintf(os.Stderr, "Error: %v [%d]\n", err, os.Getpid())
 	}
 	fmt.Printf(`
 ╭─────────────────────────────────────╮
@@ -171,11 +152,8 @@ func exit(err error) {
 │ server://password@host/host?<query> │
 │ client://password@host/host?<query> │
 │ master://hostname:port/path?<query> │
-├─────────────────────────────────────┤
-│ %-35s │
-│ %-35s │
 ╰─────────────────────────────────────╯
 
-`, 36, version, 36, fmt.Sprintf("%s/%s", runtime.GOOS, runtime.GOARCH), errMsg1, errMsg2)
+`, 36, version, 36, fmt.Sprintf("%s/%s", runtime.GOOS, runtime.GOARCH))
 	os.Exit(1)
 }
